@@ -7,6 +7,8 @@ sentry_wechat.models
 
 import json
 import requests
+from datetime import datetime
+from pytz import timezone
 from sentry.plugins.bases.notify import NotificationPlugin
 import sentry_wechat
 from django import forms
@@ -65,21 +67,21 @@ class WechatPlugin(NotificationPlugin):
             return
 
         send_url = self.get_webhook_urls(group.project)
-        title = "[{}]发生({})错误，请尽快查看处理!".format(event.project.slug,event.title)
+        title = "[{}]出bug了，快去瞧瞧!".format(event.project.slug)
         url="{}events/{}/".format(group.get_absolute_url(),event.event_id)
-
+        description="[{}]{}".format(event.title or event.message,datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S"))
         data = {
           "msgtype": "news",
-    "news": {
-       "articles" : [
-           {
-               "title" : title,
-               "description" : event.message,
-               "url" : url,
-               "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
-           }
-        ]
-    }
+            "news": {
+            "articles" : [
+                {
+                    "title" : title,
+                    "description" : description,
+                    "url" : url,
+                    "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
+                }
+                ]
+            }
         }
         requests.post(
             url=send_url,
